<template>
  <LoadingLayout :loading="isLoading" :error="isError" :loadError="refetch">
    <ContentView>
      <MyTaskCard
        :task-name="detail.taskName"
        :address="address"
        :showMyTaskArrow="false"
        :showTime="false"
      ></MyTaskCard>
      <ChunkTitle title="验收列表" />
    </ContentView>
    <InfiniteLoading
      scrollViewClassName="common-infinite-scroll-list"
      v-bind="infiniteLoadingProps"
      :key="queryState.status"
    >
      <template #renderItem="{ item }">
        <TaskCheckCard
          :avatarUrl="setOSSLink(item.avatarUrl)"
          :name="item.name"
          :genderType="item.genderType"
          :isRealName="item.isRealName"
          :contactPhone="item.contactPhone"
          :checkAcceptStatus="item.checkAcceptStatus"
          @click="goHandleTaskDetail(item)"
        />
      </template>
    </InfiniteLoading>
  </LoadingLayout>
</template>

<script setup lang="ts">
import Taro from '@tarojs/taro';
import { useQuery } from '@tanstack/vue-query';
import * as flexWorkerServices from '@12333/services/api/FlexWorker';
import { useInfiniteLoading } from '@12333/hooks';
import { OrderInputType } from '@12333/constants';
import TaskCheckCard from '../components/TaskCheckCard.vue';
import { MyTaskCard } from '@12333/components';
import { setOSSLink } from '@12333/utils';

defineOptions({
  name: 'InnerPage',
});

const router = Taro.useRouter();
const taskId = router.params?.taskId ?? '';

const {
  isLoading,
  isError,
  data: detail,
  refetch,
} = useQuery({
  queryKey: ['flexWorkerServices/getFlexTaskDto', taskId],
  queryFn: async () => {
    return await flexWorkerServices.getFlexTaskDto(
      { id: taskId },
      {
        showLoading: false,
      }
    );
  },
  placeholderData: () => ({} as API.GetFlexTaskDtoOutput),
});

const address = computed(() => {
  return `${detail.value.provinceName} ${detail.value.cityName} ${detail.value.areaName} ${detail.value.address}`;
});

const queryState = reactive({
  status: 10,
});

const { infiniteLoadingProps } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.GetFlexTaskWorkerCheckListInput = {
      pageModel: {
        rows: 20,
        page: pageParam,
        orderInput: [{ property: 'lastShelfTime', order: OrderInputType.Desc }],
      },
    };

    return flexWorkerServices.getFlexTaskWorkerCheckList(params, {
      showLoading: false,
    });
  },
  {
    queryKey: ['flexWorkerServices/getFlexTaskWorkerCheckList', queryState],
  }
);

function goHandleTaskDetail(item: API.GetNewestWorkerListOutput) {
  Taro.navigateTo({
    url: `${RouterPath.taskHandleCheckDetail}?userId=${item.userId}&taskId=${taskId}`,
  });
}
</script>
